%global selinuxtype targeted
%global modulename vncsession
%global _hardened_build 1

Summary:        A TigerVNC remote display system
Name:           tigervnc
Version:        1.12.0
Release:        4%{?dist}
License:        GPLv2+
URL:            http://www.tigervnc.com
Source0:        https://github.com/TigerVNC/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        xvnc.service
Source2:        xvnc.socket
Source3:        10-libvnc.conf
Source4:        HOWTO.md
Source5:        vncserver
Patch0001:      tigervnc-selinux-restore-context-in-case-of-different-policies.patch
Patch0002:      tigervnc-fix-typo-in-mirror-monitor-detection.patch
Patch0003:      tigervnc-root-user-selinux-context.patch
Patch0004:      tigervnc-vncsession-restore-script-systemd-service.patch
Patch3000:      tigervnc-xserver120.patch
Patch3001:      tigervnc-211.patch

# use orignal xserver source instead of those tigervnc
BuildRequires:  xorg-x11-server-source
BuildRequires:  make, gcc-c++, automake, autoconf, libtool, cmake
BuildRequires:  gettext, gettext-autopoint, desktop-file-utils
BuildRequires:  libxkbfile-devel, openssl-devel, libpciaccess-devel, fltk-devel >= 1.3.3
BuildRequires:  freetype-devel, libjpeg-turbo-devel, gnutls-devel, pam-devel
BuildRequires:  libXext-devel, libX11-devel, libXi-devel, libXfixes-devel, xorg-x11-server-devel
BuildRequires:  libXdamage-devel, libXrandr-devel, libXt-devel, libXdmcp-devel
BuildRequires:  libXinerama-devel, mesa-libGL-devel, libxshmfence-devel, pixman-devel, libdrm-devel
BuildRequires:  xorg-x11-util-macros, xorg-x11-xtrans-devel, libXtst-devel, xorg-x11-font-utils, libXfont2-devel
BuildRequires:  libselinux-devel, selinux-policy-devel, systemd, pkgconfig(systemd), selinux-policy

Requires(post): coreutils
Requires(postun):coreutils

Requires:       hicolor-icon-theme
Requires:       tigervnc-license
Requires:       tigervnc-icons

%description
Virtual Network Computing (VNC) is a remote display system which
allows you to view a computing 'desktop' environment not only on the
machine where it is running, but from anywhere on the Internet and
from a wide variety of machine architectures.  This package contains a
client which will allow you to connect to other desktops running a VNC
server.

%package server
Summary:        A TigerVNC server
Requires:       perl-interpreter
Requires:       tigervnc-server-minimal = %{version}-%{release}
Requires:       (%{name}-selinux if selinux-policy-%{selinuxtype})
Requires:       xorg-x11-xauth
Requires:       xorg-x11-xinit
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
Requires(post): systemd

%description server
The VNC system allows you to access the same desktop from a wide
variety of platforms.  This package includes set of utilities
which make usage of TigerVNC server more user friendly. It also
contains x0vncserver program which can export your active
X session.

%package server-minimal
Summary:        A minimal installation of TigerVNC server
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd
Requires(post): systemd

Requires:       mesa-dri-drivers, xkeyboard-config, xkbcomp
Requires:       tigervnc-license, dbus-x11

%description server-minimal
The VNC system allows you to access the same desktop from a wide
variety of platforms. This package contains minimal installation
of TigerVNC server, allowing others to access the desktop on your
machine.

%package server-module
Summary:        TigerVNC module to Xorg
Requires:       xorg-x11-server-Xorg
Requires:       tigervnc-license

%description server-module
This package contains libvnc.so module to X server, allowing others
to access the desktop on your machine.

%package license
Summary:        License of TigerVNC suite
BuildArch:      noarch

%description license
This package contains license of the TigerVNC suite

%package icons
Summary:        Icons for TigerVNC viewer
BuildArch:      noarch

%description icons
This package contains icons for TigerVNC viewer

%package selinux
Summary:        SELinux module for TigerVNC
BuildArch:      noarch
Requires:       selinux-policy-%{selinuxtype}
Requires:       selinux-policy
Requires(post): selinux-policy-%{selinuxtype}
Requires(post): selinux-policy-base
Requires(post): libselinux-utils
Requires(post): policycoreutils 
Requires(post): policycoreutils-python-utils

%description selinux
This package provides the SELinux policy module to ensure TigerVNC
runs properly under an environment with SELinux enabled.



%prep
%setup -q

%autopatch -p1 -m 0001 -M 0004

cp -r /usr/share/xorg-x11-server-source/* unix/xserver
pushd unix/xserver
for all in `find . -type f -perm -001`; do
        chmod -x "$all"
done
%patch3000 -p1
popd

%patch3001 -p0



%build
export CFLAGS="$RPM_OPT_FLAGS -fpic"
export CXXFLAGS="$CFLAGS -std=c++11"

%define __cmake_builddir %{_target_platform}

mkdir -p %{%__cmake_builddir}

%cmake

%cmake_build

pushd unix/xserver

sed -i 's@TIGERVNC_BUILDDIR=${TIGERVNC_SRCDIR}@TIGERVNC_BUILDDIR=${TIGERVNC_SRCDIR}/%{_target_platform}@g' hw/vnc/Makefile.am

autoreconf -fiv
%configure \
        --disable-xorg --disable-xnest --disable-xvfb --disable-dmx \
        --disable-xwin --disable-xephyr --disable-kdrive --disable-xwayland \
        --with-pic --disable-static \
        --with-default-font-path="catalogue:%{_sysconfdir}/X11/fontpath.d,built-ins" \
        --with-fontdir=%{_datadir}/X11/fonts \
        --with-xkb-output=%{_localstatedir}/lib/xkb \
        --enable-install-libxf86config \
        --enable-glx --disable-dri --enable-dri2 --disable-dri3 \
        --disable-unit-tests \
        --disable-config-hal \
        --disable-config-udev \
        --with-dri-driver-path=%{_libdir}/dri \
        --without-dtrace \
        --disable-devel-docs \
        --disable-selective-werror

make %{?_smp_mflags}
popd

pushd %{_target_platform}/media
make
popd

pushd unix/vncserver/selinux
make
popd



%install
%cmake_install
rm -f %{buildroot}%{_docdir}/%{name}-%{version}/{README.rst,LICENCE.TXT}

pushd unix/xserver/hw/vnc
%make_install
popd

pushd unix/vncserver/selinux
make install DESTDIR=%{buildroot}
popd

install -m644 %{SOURCE1} %{buildroot}%{_unitdir}/xvnc@.service
install -m644 %{SOURCE2} %{buildroot}%{_unitdir}/xvnc.socket

mkdir -p %{buildroot}%{_datadir}/icons/hicolor/{16x16,24x24,48x48}/apps

pushd media/icons
for s in 16 24 48; do
install -m644 tigervnc_$s.png %{buildroot}%{_datadir}/icons/hicolor/${s}x$s/apps/tigervnc.png
done
popd

install -m 755 %{SOURCE5} %{buildroot}/%{_bindir}/vncserver

%find_lang %{name} %{name}.lang

rm -f  %{buildroot}%{_libdir}/xorg/modules/extensions/libvnc.la

mkdir -p %{buildroot}%{_sysconfdir}/X11/xorg.conf.d/
install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/X11/xorg.conf.d/10-libvnc.conf

install -m 644 %{SOURCE4} %{buildroot}/%{_docdir}/tigervnc/HOWTO.md



%post server
%systemd_post xvnc@.service
%systemd_post xvnc.socket

%preun server
%systemd_preun xvnc@.service
%systemd_preun xvnc.socket

%postun server
%systemd_postun xvnc@.service
%systemd_postun xvnc.socket

%pre selinux
%selinux_relabel_pre -s %{selinuxtype}

%post selinux
%selinux_modules_install -s %{selinuxtype} %{_datadir}/selinux/packages/%{selinuxtype}/%{modulename}.pp.bz2
%selinux_relabel_post -s %{selinuxtype}

%postun selinux
if [ $1 -eq 0 ]; then
    %selinux_modules_uninstall -s %{selinuxtype} %{modulename}
    %selinux_relabel_post -s %{selinuxtype}
fi



%files -f %{name}.lang
%doc README.rst
%{_bindir}/vncviewer
%{_datadir}/applications/*
%{_mandir}/man1/vncviewer.1*

%files server
%config(noreplace) %{_sysconfdir}/pam.d/tigervnc
%config(noreplace) %{_sysconfdir}/tigervnc/vncserver-config-defaults
%config(noreplace) %{_sysconfdir}/tigervnc/vncserver-config-mandatory
%config(noreplace) %{_sysconfdir}/tigervnc/vncserver.users
%{_unitdir}/vncserver@.service
%{_unitdir}/xvnc@.service
%{_unitdir}/xvnc.socket
%{_bindir}/vncserver
%{_bindir}/x0vncserver
%{_sbindir}/vncsession
%{_libexecdir}/vncserver
%{_libexecdir}/vncsession-start
%{_libexecdir}/vncsession-restore
%{_mandir}/man1/x0vncserver.1*
%{_mandir}/man8/vncserver.8*
%{_mandir}/man8/vncsession.8*
%{_docdir}/tigervnc/HOWTO.md

%files server-minimal
%{_bindir}/vncconfig
%{_bindir}/vncpasswd
%{_bindir}/Xvnc
%{_mandir}/man1/Xvnc.1*
%{_mandir}/man1/vncpasswd.1*
%{_mandir}/man1/vncconfig.1*

%files server-module
%{_libdir}/xorg/modules/extensions/libvnc.so
%config(noreplace) %{_sysconfdir}/X11/xorg.conf.d/10-libvnc.conf

%files license
%{_docdir}/tigervnc/LICENCE.TXT

%files icons
%{_datadir}/icons/hicolor/*/apps/*

%files selinux
%{_datadir}/selinux/packages/%{selinuxtype}/%{modulename}.pp.*
%ghost %verify(not md5 size mtime) %{_sharedstatedir}/selinux/%{selinuxtype}/active/modules/200/%{modulename}



%changelog
* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.12.0-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 1.12.0-3
- Rebuilt for OpenCloudOS Stream 23

* Fri Dec 9 2022 Zhao Zhen <jeremiazhao@tencent.com> - 1.12.0-2
- rebuild for OpenCloudOS Stream preview

* Mon Nov 14 2022 Zhao Zhen <jeremiazhao@tencent.com> - 1.12.0-1
- initial building
